***************
Practicalities
***************

Installation
============

PiPy::

  pip install pydoas
  
Conda::

  conda install -c conda-forge pydoas

Or you can clone the `Github repo <https://github.com/jgliss/pydoas>` and install from source from the toplevel folder::

  pip install . 

Getting started
===============

After installation try running the :ref:`examples` in order to test the installation and familiarise yourself with the - quite limited - 
functionality of this cute little library. 

Copyright
=========

Copyright (C) 2017 Jonas Gliss (jonasgliss@gmail.com)

This program is free software: you can redistribute it and/or modify it under the terms of the BSD 3-Clause License

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See BSD 3-Clause License for more details (https://opensource.org/licenses/BSD-3-Clause)
